module.exports = defineTest({
	description: 'Inserts space when simplifying yield expression without space'
});
